@@ -3,17 +3,17 @@ import re
 import sys
 
 from .job import Job  # noqa
-from .run import run, run_by_cron, run_periodically  # noqa
+from .run import combine, run, run_by_cron, run_periodically  # noqa
 
 try:
-    import aiohttp  # noqa
+    import aiohttp as _aiohttp  # noqa
 
     from .aiohttp import is_healthy as aiohttp_is_healthy, setup_ctx as aiohttp_setup_ctx  # noqa
 except ImportError:
     pass
 
 
-__version__ = "0.0.3"
+__version__ = "0.0.4"
 
 version = f"{__version__}, Python {sys.version}"
 
